package com.ruoyi.jarvis.service;

import com.ruoyi.jarvis.domain.ProductJdConfig;
import java.util.List;

/**
 * 产品京东配置Service接口
 * 
 * @author ruoyi
 */
public interface IProductJdConfigService 
{
    /**
     * 查询产品京东配置列表
     * 
     * @return 产品京东配置集合
     */
    public List<ProductJdConfig> selectProductJdConfigList();

    /**
     * 查询产品京东配置
     * 
     * @param productModel 产品型号
     * @return 产品京东配置
     */
    public ProductJdConfig selectProductJdConfigByModel(String productModel);

    /**
     * 新增产品京东配置
     * 
     * @param productJdConfig 产品京东配置
     * @return 结果
     */
    public int insertProductJdConfig(ProductJdConfig productJdConfig);

    /**
     * 修改产品京东配置
     * 
     * @param productJdConfig 产品京东配置
     * @return 结果
     */
    public int updateProductJdConfig(ProductJdConfig productJdConfig);

    /**
     * 批量删除产品京东配置
     * 
     * @param productModels 需要删除的产品型号集合
     * @return 结果
     */
    public int deleteProductJdConfigByModels(String[] productModels);

    /**
     * 删除产品京东配置信息
     * 
     * @param productModel 产品型号
     * @return 结果
     */
    public int deleteProductJdConfigByModel(String productModel);

    /**
     * 根据产品型号获取京东链接
     * 
     * @param productModel 产品型号
     * @return 京东链接
     */
    public String getJdUrlByProductModel(String productModel);

    /**
     * 初始化默认数据
     */
    public void initDefaultData();
}

